-- Drop the existing database 'db'
DROP DATABASE IF EXISTS stops_db;

-- Create the new database 'stops_db'
CREATE DATABASE stops_db CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- Use the new database
USE stops_db;

-- Create the stops table
CREATE TABLE stops (
    id INT AUTO_INCREMENT PRIMARY KEY,
    sloid VARCHAR(100),
    stop_type VARCHAR(50),   -- 'matched', 'station', 'unmatched', 'osm'
    match_type VARCHAR(50),  -- e.g. 'exact', 'name', 'distance_matching_1'
    
    -- ATLAS attributes
    atlas_designation VARCHAR(255),           -- ATLAS designation (from CSV)
    atlas_designation_official VARCHAR(255),  -- Official designation (from CSV or fallback)
    atlas_lat FLOAT,                         -- ATLAS latitude (wgs84North)
    atlas_lon FLOAT,                         -- ATLAS longitude (wgs84East)
    atlas_business_org_abbr VARCHAR(100),     -- ATLAS servicePointBusinessOrganisationAbbreviationEn
    
    -- UIC Reference (merged field from ATLAS number and OSM uic_ref)
    uic_ref VARCHAR(100),         -- UIC reference from either source
    
    -- OSM attributes
    osm_node_id VARCHAR(100),   -- OSM node identifier
    osm_local_ref VARCHAR(100), -- OSM "local_ref" tag
    osm_name VARCHAR(255),      -- OSM stop name (for display)
    osm_uic_name VARCHAR(255),  -- OSM "uic_name" attribute, if available
    osm_network VARCHAR(255),   -- OSM "network" tag
    osm_operator VARCHAR(255),  -- OSM "operator" tag
    osm_public_transport VARCHAR(255),  -- public_transport tag
    osm_lat FLOAT,             -- OSM latitude (if applicable)
    osm_lon FLOAT,             -- OSM longitude (if applicable)
    
    distance_m FLOAT,  -- Distance between ATLAS and OSM coordinates (if matched)
    
    -- Route information as JSON lists
    routes_atlas JSON,  -- List of {route_id, direction_id, route_short_name} for ATLAS 
    routes_osm JSON,    -- List of {route_id, direction_id, route_short_name} for OSM
    
    INDEX (sloid),
    INDEX (osm_node_id),
    INDEX (uic_ref)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


-- Create the routes_and_directions table
CREATE TABLE routes_and_directions (
    id INT AUTO_INCREMENT PRIMARY KEY,
    direction_id VARCHAR(20),
    osm_route_id VARCHAR(100),
    osm_nodes_json JSON,        -- List of node_ids that belong to this OSM route
    atlas_route_id VARCHAR(100),
    atlas_sloids_json JSON,     -- List of sloids that belong to this ATLAS route
    route_name VARCHAR(255),
    route_short_name VARCHAR(50),
    route_long_name VARCHAR(255),
    route_type VARCHAR(50),
    match_type VARCHAR(50),     -- 'matched', 'osm_only', 'atlas_only'
    INDEX (osm_route_id, direction_id),
    INDEX (atlas_route_id, direction_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;