def standardize_operator(operator):
    """
    Standardize operator names:
    - Convert CFF or FFS to SBB
    - Convert BLT Auto to BLT
    - Convert Compagnie générale de navigation sur le lac Léman (CGN) to CGN
    - Convert Stiftung Luftseilbahn Reigoldswil-Wasserfallen to LRW
    - Convert FART to FART Auto
    - Convert PostAuto Berner Oberland to PAG
    - Convert TPF to TPF Auto
    - Convert TRAVYS Auto to TRAVYSAuto
    - Convert VBZ/DBZ to VBZ
    - Convert afa to AFA
    - Convert Bus Sierrois to BS
    - Convert Busland AG to BLAG
    - Convert CarPostal to PAG
    - Convert Giovanni Frapolli to GFR
    - Convert PAG/RA to PAG
    - Convert PAG; TPC to TPC Auto
    - Convert TMR to TMR Auto
    - Convert TRAVYS to TRAVYSAuto
    - Convert TéléOvronnaz to TOJ
    - Convert VBSH to VBSH-rv
    - Convert tpf to TPF Auto
    - Convert Transports Publics Fribourgeois to TPF Auto
    - Convert Transports Publics Fribourgoise SA to TPF Auto
    - Convert Transports publics fribourgeois to TPF Auto
    """
    if not operator:
        return operator
        
    if operator in ["CFF", "FFS"]:
        return "SBB"
    elif operator == "BLT Auto":
        return "BLT"
    elif operator == "Compagnie générale de navigation sur le lac Léman (CGN)":
        return "CGN"
    elif operator == "Stiftung Luftseilbahn Reigoldswil-Wasserfallen":
        return "LRW"
    elif operator == "FART":
        return "FART Auto"
    elif operator == "PostAuto Berner Oberland":
        return "PAG"
    elif operator == "TPF" or operator.lower() == "tpf":
        return "TPF Auto"
    elif operator in ["Transports Publics Fribourgeois", "Transports Publics Fribourgoise SA", "Transports publics fribourgeois"]:
        return "TPF Auto"
    elif operator == "TRAVYS Auto":
        return "TRAVYSAuto"
    elif operator == "TRAVYS":
        return "TRAVYSAuto"
    elif operator.lower() == "afa":
        return "AFA"
    elif operator == "Bus Sierrois":
        return "BS"
    elif operator == "Busland AG":
        return "BLAG"
    elif operator == "CarPostal":
        return "PAG"
    elif operator == "Giovanni Frapolli":
        return "GFR"
    elif operator == "PAG/RA":
        return "PAG"
    elif operator == "PAG; TPC":
        return "TPC Auto"
    elif operator == "TMR":
        return "TMR Auto"
    elif operator == "TéléOvronnaz":
        return "TOJ"
    elif operator == "VBSH":
        return "VBSH-rv"
    return operator